@@ -1541,7 +1541,7 @@ char *StringFormatTimePeriod(time_t seconds)
 	if(seconds < 60)
 	{
 	    sprintf(s, "%ld sec%s",
-		seconds,
+		(long)seconds,
 		((seconds > 1) ? "s" : "")
 	    );
 	}
@@ -1549,7 +1549,7 @@ char *StringFormatTimePeriod(time_t seconds)
 	{
 	    seconds = seconds / 60;
 	    sprintf(s, "%ld min%s",
-		seconds,
+		(long)seconds,
 		((seconds > 1) ? "s" : "")
 	    );
 	}
@@ -1557,7 +1557,7 @@ char *StringFormatTimePeriod(time_t seconds)
 	{
 	    seconds = seconds / 3600;
 	    sprintf(s, "%ld hour%s",
-		seconds,
+		(long)seconds,
 		((seconds > 1) ? "s" : "")
 	    );
 	}
@@ -1565,7 +1565,7 @@ char *StringFormatTimePeriod(time_t seconds)
 	{
 	    seconds = seconds / 86400;
 	    sprintf(s, "%ld day%s",
-		seconds,
+		(long)seconds,
 		((seconds > 1) ? "s" : "")
 	    );
 	}
